# Read the dataset 'skivefjord2_data.csv' into R
D <- read.table("skivefjord2_data.csv", header = TRUE, sep = ";")


# Add log-chlorophyl to the dataset
D$logchlorophyl <- log(D$chlorophyl)


# Subset containing the first 234 observations (for model estimation)
D_model <- D[1:234, ]

# Subset containing the last 6 observations (for validation)
D_test <- D[235:240,]


# Estimate multiple linear regression model
fit <- lm(logchlorophyl ~ totalP + temp, data = D_model)

# Show parameter estimates etc.
summary(fit)


# Plots for model validation

# Observations against fitted values
plot(fit$fitted.values, D_model$logchlorophyl, 
     xlab = "Fitted values", ylab = "log(chlorophyl concentration)")

# Residuals against each of the explanatory variables
plot(D_model$EXPLANATORY_VARIABLE, fit$residuals, 
        xlab = "INSERT TEXT", ylab = "Residuals")

# Residuals against fitted values
plot(fit$fitted.values, fit$residuals, xlab = "Fitted values", 
     ylab = "Residuals")

# Normal QQ-plot of the residuals
qqnorm(fit$residuals, ylab = "Residuals", xlab = "Z-scores", 
       main = "")
qqline(fit$residuals)


# Confidence intervals for the model coefficients
confint(fit, level = 0.95)


# Predictions and 95% prediction intervals
pred <- predict(FINAL_MODEL, newdata = D_test, 
                interval = "prediction", level = 0.95)

# Observed values and predictions
cbind(year = D_test$year, month = D_test$month, 
      logchlorophyl = D_test$logchlorophyl, pred)

